@@ -170,10 +170,10 @@ if __name__ == '__main__':
         for key, value in vals1.items():
             text = text.replace("${}$".format(key), str(value))
 
-        with open(cacheDir+filename + ".tex", "w", encoding="utf-8") as output:
+        with open(cacheDir+"\\"+filename + ".tex", "w", encoding="utf-8") as output:
             output.write(text)
 
-    os.system("pdflatex -output-directory=" +cacheDir +"\\"+ filename + ".tex")
+    os.system("pdflatex -output-directory=" +cacheDir +" "+ cacheDir+ "\\" +filename    + ".tex")
     os.system("move " + cacheDir+"\\"+filename + ".pdf " + invoiceDir)
     win1.close()
 
